/**
 * @file List of all resource constants
 * @description A resource is defined by an HTTP Verb such as GET, POST, PUT & DELETE and
 * the endpoint which is requested by the user. These constants are used as a normalized
 * standard to label different entities across modules
 * @author Abhishek Sharma
 * @copyright 2016-2017 Streamingo Solutions Private Limited. All Rights Reserved.
 */


/**
 * @namespace ResourceConstants
 */
(function () {
  "use strict";

  /**
   * @type {object}
   * @default
   */
  var Resources = {},

    Roles = require("./user-roles");

  Resources.GET_ORGANIZATIONS = {
    action: "GET_ORGANIZATIONS",
    resource: "ORGANIZATIONS",
    verb: "GET",
    endpoint: "/organizations",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["organizationId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "organizations",
    label: "list organizations",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ORGANIZATIONS_REGISTER = {
    action: "ORGANIZATIONS_REGISTER",
    resource: "ORGANIZATIONS",
    verb: "POST",
    endpoint: "/organizations/register",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["organizationId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "organization register",
    label: "register organization",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_ORGANIZATION = {
    action: "UPDATE_ORGANIZATION",
    resource: "ORGANIZATIONS",
    verb: "PUT",
    endpoint: "/organizations",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["organizationId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "organizations",
    label: "update organization",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_ORGANIZATION = {
    action: "DELETE_ORGANIZATION",
    resource: "ORGANIZATIONS",
    verb: "DELETE",
    endpoint: "/organizations",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["organizationId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "organizations",
    label: "delete organization",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_USERS = {
    action: "GET_USERS",
    resource: "USERS",
    verb: "GET",
    endpoint: "/users",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["userId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "users",
    label: "list users",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.USERS_REGISTER = {
    action: "USERS_REGISTER",
    resource: "USERS",
    verb: "POST",
    endpoint: "/users/register",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["userId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user register",
    label: "register user",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.USERS_LOGIN = {
    action: "USERS_LOGIN",
    resource: "USERS",
    verb: "POST",
    endpoint: "/users/login",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["userId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "users login",
    label: "login user",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_USER = {
    action: "UPDATE_USER",
    resource: "USERS",
    verb: "PUT",
    endpoint: "/users",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["userId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "users",
    label: "update user",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DISABLE_USER = {
    action: "DISABLE_USER",
    resource: "USERS",
    verb: "PUT",
    endpoint: "/users/disable",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["userId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "users",
    label: "disable user",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_USER = {
    action: "DELETE_USER",
    resource: "USERS",
    verb: "DELETE",
    endpoint: "/users",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["userId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "users",
    label: "delete user",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_USER_PASSWORD = {
    action: "UPDATE_USER_PASSWORD",
    resource: "USERS",
    verb: "PUT",
    endpoint: "/users/password",
    sign_with: "TOKEN",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user password",
    label: "update user password",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.RESET_USER_PASSWORD = {
    action: "RESET_USER_PASSWORD",
    resource: "USERS",
    verb: "PUT",
    endpoint: "/users/password/reset",
    sign_with: "",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user password",
    label: "reset user password",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  /* ------------------- CLUSTER --------------------- */

  Resources.GET_CLUSTERS = {
    action: "GET_CLUSTERS",
    resource: "CLUSTER",
    verb: "GET",
    endpoint: "/clusters",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["clusterId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "clusters",
    label: "list clusters",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_CLUSTER = {
    action: "ADD_CLUSTER",
    resource: "CLUSTER",
    verb: "POST",
    endpoint: "/clusters",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "add cluster",
    label: "add cluster",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_CLUSTER = {
    action: "UPDATE_CLUSTER",
    resource: "CLUSTER",
    verb: "PUT",
    endpoint: "/clusters",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster",
    label: "update cluster",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_CLUSTER_OWNER = {
    action: "UPDATE_CLUSTER_OWNER",
    resource: "CLUSTER",
    verb: "PUT",
    endpoint: "/clusters/owner",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster",
    label: "update cluster",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_CLUSTER = {
    action: "DELETE_CLUSTER",
    resource: "CLUSTER",
    verb: "DELETE",
    endpoint: "/clusters",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster",
    label: "delete cluster",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /* ------------------- CLUSTER --------------------- */

  /* ------------------- CLUSTER_MEMBER --------------------- */

  Resources.GET_CLUSTER_MEMBERS = {
    action: "GET_CLUSTER_MEMBERS",
    resource: "CLUSTER_MEMBER",
    verb: "GET",
    endpoint: "/clusters/members",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["clusterMemberId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster_member",
    label: "list cluster members",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_CLUSTER_MEMBER = {
    action: "ADD_CLUSTER_MEMBER",
    resource: "CLUSTER_MEMBER",
    verb: "POST",
    endpoint: "/clusters/members",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterMemberId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster_member",
    label: "add cluster member",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  // Resources.UPDATE_CLUSTER_MEMBER = {
  //   action: "UPDATE_CLUSTER_MEMBER",
  //   resource: "CLUSTER_MEMBER",
  //   verb: "PUT",
  //   endpoint: "/clusters/members",
  //   sign_with: "TOKEN",
  //   type: "WRITE",
  //   resource_ids: ["clusterMemberId"],
  //   request_processing_type: "SERIAL",
  //   API: "Labelling_API",
  //   feature_name: "cluster_member",
  //   label: "update cluster member",
  //   role_acl: [
  //     {
  //       role: Roles.PUBLISHER.role,
  //       account_restriction: true
  //     },
  //     {
  //       role: Roles.ADMIN.role,
  //       account_restriction: false
  //     },
  //     {
  //       role: Roles.ROOT.role,
  //       account_restriction: false
  //     }
  //   ]
  // };

  Resources.DELETE_CLUSTER_MEMBER = {
    action: "DELETE_CLUSTER_MEMBER",
    resource: "CLUSTER_MEMBER",
    verb: "DELETE",
    endpoint: "/clusters/members",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterMemberId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster_member",
    label: "delete cluster member",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /* ------------------- CLUSTER_MEMBER --------------------- */

  /* ------------------- CLUSTER_PROJECT_MAP --------------------- */

  Resources.GET_CLUSTER_PROJECT_MAPS = {
    action: "GET_CLUSTER_PROJECT_MAPS",
    resource: "CLUSTER_PROJECT_MAP",
    verb: "GET",
    endpoint: "/clusters/projectmaps",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["clusterProjectMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster_project_map",
    label: "list cluster project_maps",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_CLUSTER_PROJECT_MAP = {
    action: "ADD_CLUSTER_PROJECT_MAP",
    resource: "CLUSTER_PROJECT_MAP",
    verb: "POST",
    endpoint: "/clusters/projectmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterProjectMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster_project_map",
    label: "add cluster project_map",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  // Resources.UPDATE_CLUSTER_PROJECT_MAP = {
  //   action: "UPDATE_CLUSTER_PROJECT_MAP",
  //   resource: "CLUSTER_PROJECT_MAP",
  //   verb: "PUT",
  //   endpoint: "/clusters/projectmaps",
  //   sign_with: "TOKEN",
  //   type: "WRITE",
  //   resource_ids: ["clusterProjectMapId"],
  //   request_processing_type: "SERIAL",
  //   API: "Labelling_API",
  //   feature_name: "cluster_project_map",
  //   label: "update cluster project_map",
  //   role_acl: [
  //     {
  //       role: Roles.PUBLISHER.role,
  //       account_restriction: true
  //     },
  //     {
  //       role: Roles.ADMIN.role,
  //       account_restriction: false
  //     },
  //     {
  //       role: Roles.ROOT.role,
  //       account_restriction: false
  //     }
  //   ]
  // };

  Resources.DELETE_CLUSTER_PROJECT_MAP = {
    action: "DELETE_CLUSTER_PROJECT_MAP",
    resource: "CLUSTER_PROJECT_MAP",
    verb: "DELETE",
    endpoint: "/clusters/projectmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["clusterProjectMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "cluster_project_map",
    label: "delete cluster project_map",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  /* ------------------- CLUSTER_PROJECT_MAP --------------------- */

  /* ------------------- PROJECTS --------------------- */

  Resources.GET_PROJECTS = {
    action: "GET_PROJECTS",
    resource: "PROJECT",
    verb: "GET",
    endpoint: "/projects",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "projects",
    label: "list projects",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_PROJECT = {
    action: "ADD_PROJECT",
    resource: "PROJECT",
    verb: "POST",
    endpoint: "/projects",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "add project",
    label: "add project",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_PROJECT = {
    action: "UPDATE_PROJECT",
    resource: "PROJECT",
    verb: "PUT",
    endpoint: "/projects",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "project",
    label: "update project",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_PROJECT_OWNER = {
    action: "UPDATE_PROJECT_OWNER",
    resource: "PROJECT",
    verb: "PUT",
    endpoint: "/projects/owner",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "project",
    label: "update project",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_PROJECT = {
    action: "DELETE_PROJECT",
    resource: "PROJECT",
    verb: "DELETE",
    endpoint: "/projects",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "project",
    label: "delete project",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_PROJECT_MEMBERS = {
    action: "GET_PROJECT_MEMBERS",
    resource: "PROJECT_MEMBER",
    verb: "GET",
    endpoint: "/projects/members",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "project_member",
    label: "list project members",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_PROJECT_MEMBER = {
    action: "ADD_PROJECT_MEMBER",
    resource: "PROJECT_MEMBER",
    verb: "POST",
    endpoint: "/projects/members",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "project_member",
    label: "add project member",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  // Resources.UPDATE_PROJECT_MEMBER = {
  //   action: "UPDATE_PROJECT_MEMBER",
  //   resource: "PROJECT_MEMBER",
  //   verb: "PUT",
  //   endpoint: "/projects/members",
  //   sign_with: "TOKEN",
  //   type: "WRITE",
  //   resource_ids: ["projectId"],
  //   request_processing_type: "SERIAL",
  //   API: "Labelling_API",
  //   feature_name: "project_member",
  //   label: "update project member",
  //   role_acl: [
  //     {
  //       role: Roles.PUBLISHER.role,
  //       account_restriction: true
  //     },
  //     {
  //       role: Roles.ADMIN.role,
  //       account_restriction: false
  //     },
  //     {
  //       role: Roles.ROOT.role,
  //       account_restriction: false
  //     }
  //   ]
  // };

  Resources.DELETE_PROJECT_MEMBER = {
    action: "DELETE_PROJECT_MEMBER",
    resource: "PROJECT_MEMBER",
    verb: "DELETE",
    endpoint: "/projects/members",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["projectId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "project_member",
    label: "delete project member",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_VIDEOS = {
    action: "GET_VIDEOS",
    resource: "VIDEO",
    verb: "GET",
    endpoint: "/projects/videos",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "videos",
    label: "list videos",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_VIDEO_URL = {
    action: "GET_VIDEO_URL",
    resource: "VIDEO",
    verb: "GET",
    endpoint: "/projects/videos/video-url",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video url",
    label: "list video url",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_VIDEO = {
    action: "ADD_VIDEO",
    resource: "VIDEO",
    verb: "POST",
    endpoint: "/projects/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "add video",
    label: "add video",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO = {
    action: "UPDATE_VIDEO",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video",
    label: "update video",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO_EXTRACTION_POINTS = {
    action: "UPDATE_VIDEO_EXTRACTION_POINTS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/extractions",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "extraction points",
    label: "update extraction points",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO_WORKERS = {
    action: "UPDATE_VIDEO_WORKERS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/workers",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video workers",
    label: "update video workers",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_LABELLING_STATUS = {
    action: "UPDATE_LABELLING_STATUS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/status",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video status",
    label: "update video status",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_EXTRACTION_STATUS = {
    action: "UPDATE_EXTRACTION_STATUS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/status/extraction",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video extraction status",
    label: "update video extraction status",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFERENCE_STATUS = {
    action: "UPDATE_INFERENCE_STATUS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/status/inference",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video inference status",
    label: "update video inference status",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFERENCE_PROGRESS = {
    action: "UPDATE_INFERENCE_PROGRESS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/status/inference/progress",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video inference progress",
    label: "update video inference progress",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_LABEL_STATUS = {
    action: "UPDATE_LABEL_STATUS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/status/label",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video label status",
    label: "update video label status",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_REVIEW_STATUS = {
    action: "UPDATE_REVIEW_STATUS",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/status/review",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video review status",
    label: "update video review status",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO_METADATA = {
    action: "UPDATE_VIDEO_METADATA",
    resource: "VIDEO",
    verb: "PUT",
    endpoint: "/projects/videos/metadata",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video meta data",
    label: "update video meta data",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_VIDEO = {
    action: "DELETE_VIDEO",
    resource: "VIDEO",
    verb: "DELETE",
    endpoint: "/projects/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video",
    label: "delete video",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_VIDEO_TASKS = {
    action: "GET_VIDEO_TASKS",
    resource: "VIDEO_TASK",
    verb: "GET",
    endpoint: "/projects/videos/tasks",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_VIDEO_TASKS = {
    action: "ADD_VIDEO_TASKS",
    resource: "VIDEO_TASK",
    verb: "POST",
    endpoint: "/projects/videos/tasks",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO_TASKS = {
    action: "UPDATE_VIDEO_TASKS",
    resource: "VIDEO_TASK",
    verb: "PUT",
    endpoint: "/projects/videos/tasks",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO_TASKS_LAST_WORKED = {
    action: "UPDATE_VIDEO_TASKS_LAST_WORKED",
    resource: "VIDEO_TASK",
    verb: "PUT",
    endpoint: "/projects/videos/tasks/last-worked",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_VIDEO_TASKS = {
    action: "DELETE_VIDEO_TASKS",
    resource: "VIDEO_TASK",
    verb: "DELETE",
    endpoint: "/projects/videos/tasks",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_VIDEO_FRAMES= {
    action: "GET_VIDEO_FRAMES",
    resource: "FRAMES",
    verb: "GET",
    endpoint: "/projects/videos/frames",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["frameId", "videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "frames",
    label: "list frames",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_VIDEO_FRAMES = {
    action: "ADD_VIDEO_FRAMES",
    resource: "FRAMES",
    verb: "POST",
    endpoint: "/projects/videos/frames",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "frames",
    label: "add frames",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO_FRAMES = {
    action: "UPDATE_VIDEO_FRAMES",
    resource: "FRAMES",
    verb: "PUT",
    endpoint: "/projects/videos/frames",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["frameId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "frames",
    label: "update frames",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_VIDEO_FRAMES_LABEL_REVIEW = {
    action: "UPDATE_VIDEO_FRAMES_LABEL_REVIEW",
    resource: "FRAMES",
    verb: "PUT",
    endpoint: "/projects/videos/frames/label-review",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["frameId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "frames label review",
    label: "update frame label review",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_VIDEO_FRAMES = {
    action: "DELETE_VIDEO_FRAMES",
    resource: "FRAMES",
    verb: "DELETE",
    endpoint: "/projects/videos/frames",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["frameId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "frames",
    label: "delete frames",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

/* ------------------- FRAMEDETECTIONS --------------------- */
Resources.GET_VIDEO_FRAME_DETECTIONS= {
  action: "GET_VIDEO_FRAME_DETECTIONS",
  resource: "FRAME_DETECTIONS",
  verb: "GET",
  endpoint: "/projects/videos/frames/detections",
  sign_with: "TOKEN",
  type: "READ",
  resource_ids: ["frameDetectionId", "frameId"],
  request_processing_type: "SERIAL",
  API: "Labelling_API",
  feature_name: "frameDetections",
  label: "list frameDetections",
  role_acl: [
    {
      role: Roles.WORKER.role,
      account_restriction: true
    },
    {
      role: Roles.PUBLISHER.role,
      account_restriction: true
    },
    {
      role: Roles.ADMIN.role,
      account_restriction: false
    },
    {
      role: Roles.ROOT.role,
      account_restriction: false
    }
  ]
};

Resources.ADD_VIDEO_FRAME_DETECTIONS = {
  action: "ADD_VIDEO_FRAME_DETECTIONS",
  resource: "FRAME_DETECTIONS",
  verb: "POST",
  endpoint: "/projects/videos/frames/detections",
  sign_with: "TOKEN",
  type: "WRITE",
  resource_ids: ["frameId"],
  request_processing_type: "SERIAL",
  API: "Labelling_API",
  feature_name: "frameDetections",
  label: "add frameDetections",
  role_acl: [
    {
      role: Roles.ADMIN.role,
      account_restriction: false
    },
    {
      role: Roles.ROOT.role,
      account_restriction: false
    }
  ]
};

Resources.UPDATE_VIDEO_FRAME_DETECTIONS = {
  action: "UPDATE_VIDEO_FRAME_DETECTIONS",
  resource: "FRAME_DETECTIONS",
  verb: "PUT",
  endpoint: "/projects/videos/frames/detections",
  sign_with: "TOKEN",
  type: "WRITE",
  resource_ids: ["frameDetectionId"],
  request_processing_type: "SERIAL",
  API: "Labelling_API",
  feature_name: "frameDetections",
  label: "update frameDetections",
  role_acl: [
    {
      role: Roles.ADMIN.role,
      account_restriction: false
    },
    {
      role: Roles.ROOT.role,
      account_restriction: false
    }
  ]
};

Resources.DELETE_VIDEO_FRAME_DETECTIONS = {
  action: "DELETE_VIDEO_FRAME_DETECTIONS",
  resource: "FRAME_DETECTIONS",
  verb: "DELETE",
  endpoint: "/projects/videos/frames/detections",
  sign_with: "TOKEN",
  type: "WRITE",
  resource_ids: ["frameDetectionId"],
  request_processing_type: "SERIAL",
  API: "Labelling_API",
  feature_name: "frameDetections",
  label: "delete frameDetections",
  role_acl: [
    {
      role: Roles.ADMIN.role,
      account_restriction: false
    },
    {
      role: Roles.ROOT.role,
      account_restriction: false
    }
  ]
};
/* ------------------- FRAMEDETECTIONS --------------------- */

  Resources.GET_LABELS = {
    action: "GET_LABELS",
    resource: "LABELS",
    verb: "GET",
    endpoint: "/labels",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["frameId", "labelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labels",
    label: "list labels",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_LABELS = {
    action: "ADD_LABELS",
    resource: "LABELS",
    verb: "POST",
    endpoint: "/labels",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labels",
    label: "add label",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_LABELS = {
    action: "UPDATE_LABELS",
    resource: "LABELS",
    verb: "PUT",
    endpoint: "/labels",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["labelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labels",
    label: "update label",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_LABELS = {
    action: "DELETE_LABELS",
    resource: "LABELS",
    verb: "DELETE",
    endpoint: "/labels",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["labelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labels",
    label: "delete label",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_LABELS_CATEGORIES = {
    action: "GET_LABELS_CATEGORIES",
    resource: "LABELS",
    verb: "GET",
    endpoint: "/labels/categories",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["frameId", "labelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labels categories",
    label: "list labels categories",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  /* ------------------- LABELPROJECTMAPS --------------------- */

  Resources.GET_LABEL_PROJECT_MAPS = {
    action: "GET_LABEL_PROJECT_MAPS",
    resource: "LABELPROJECTMAPS",
    verb: "GET",
    endpoint: "/labels/projectmaps",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["labelProjectMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labelProjectMaps",
    label: "list labelProjectMaps",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_LABEL_PROJECT_MAPS = {
    action: "ADD_LABEL_PROJECT_MAPS",
    resource: "LABELPROJECTMAPS",
    verb: "POST",
    endpoint: "/labels/projectmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["labelProjectMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labelProjectMaps",
    label: "add labelProjectMaps",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_LABEL_PROJECT_MAPS = {
    action: "UPDATE_LABEL_PROJECT_MAPS",
    resource: "LABELPROJECTMAPS",
    verb: "PUT",
    endpoint: "/labels/projectmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["labelProjectMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labelProjectMaps",
    label: "update labelProjectMaps",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_LABEL_PROJECT_MAPS = {
    action: "DELETE_LABEL_PROJECT_MAPS",
    resource: "LABELPROJECTMAPS",
    verb: "DELETE",
    endpoint: "/labels/projectmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["labelProjectMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "labelProjectMaps",
    label: "delete labelProjectMaps",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /* ------------------- LABELPROJECTMAPS --------------------- */

  /* ------------------- DLMODEL --------------------- */
  Resources.GET_DLMODEL = {
    action: "GET_DLMODEL",
    resource: "DLMODEL",
    verb: "GET",
    endpoint: "/dlmodels",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel",
    label: "list dlmodel",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_DLMODEL = {
    action: "ADD_DLMODEL",
    resource: "DLMODEL",
    verb: "POST",
    endpoint: "/dlmodels",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel",
    label: "add dlmodel",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL = {
    action: "UPDATE_DLMODEL",
    resource: "DLMODEL",
    verb: "PUT",
    endpoint: "/dlmodels",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel",
    label: "update dlmodel",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.RETRAIN_DLMODEL = {
    action: "RETRAIN_DLMODEL",
    resource: "DLMODEL",
    verb: "POST",
    endpoint: "/dlmodels/retrain",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel",
    label: "update dlmodel",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL_STATUS = {
    action: "UPDATE_DLMODEL_STATUS",
    resource: "DLMODEL",
    verb: "PUT",
    endpoint: "/dlmodels/status",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel status",
    label: "update dlmodel status",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL_STATUS_PROGRESS = {
    action: "UPDATE_DLMODEL_STATUS_PROGRESS",
    resource: "DLMODEL",
    verb: "PUT",
    endpoint: "/dlmodels/status/progress",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel status",
    label: "update dlmodel status",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL_ACCURACY = {
    action: "UPDATE_DLMODEL_ACCURACY",
    resource: "DLMODEL",
    verb: "PUT",
    endpoint: "/dlmodels/accuracy",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel accuracy",
    label: "update dlmodel accuracy",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL_SUBMISSION_STATUS = {
    action: "UPDATE_DLMODEL_SUBMISSION_STATUS",
    resource: "DLMODEL",
    verb: "PUT",
    endpoint: "/dlmodels/status/submission",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel submission status",
    label: "update dlmodel submission status",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_DLMODEL = {
    action: "DELETE_DLMODEL",
    resource: "DLMODEL",
    verb: "DELETE",
    endpoint: "/dlmodels",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel",
    label: "delete dlmodel",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /* ------------------- DLMODEL --------------------- */

  /* ------------------- DLMODELLABELMAP --------------------- */
  Resources.GET_DLMODEL_LABEL_MAP = {
    action: "GET_DLMODEL_LABEL_MAP",
    resource: "DLMODELLABELMAP",
    verb: "GET",
    endpoint: "/dlmodels/labelmaps",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["dlModelLabelMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel_labelmap",
    label: "list dlmodel labelmaps",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_DLMODEL_LABEL_MAP = {
    action: "ADD_DLMODEL_LABEL_MAP",
    resource: "DLMODELLABELMAP",
    verb: "POST",
    endpoint: "/dlmodels/labelmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelLabelMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel_labelmap",
    label: "add dlmodel labelmap",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL_LABEL_MAP = {
    action: "UPDATE_DLMODEL_LABEL_MAP",
    resource: "DLMODELLABELMAP",
    verb: "PUT",
    endpoint: "/dlmodels/labelmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelLabelMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel_labelmap",
    label: "update dlmodel labelmap",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_DLMODEL_LABEL_MAP = {
    action: "DELETE_DLMODEL_LABEL_MAP",
    resource: "DLMODELLABELMAP",
    verb: "DELETE",
    endpoint: "/dlmodels/labelmaps",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelLabelMapId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel_labelmap",
    label: "delete dlmodel labelmap",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /* ------------------- DLMODELLABELMAP --------------------- */

  /* ------------------- DLMODELVIDEO --------------------- */
  Resources.GET_DLMODEL_VIDEO = {
    action: "GET_DLMODEL_VIDEO",
    resource: "DLMODELVIDEO",
    verb: "GET",
    endpoint: "/dlmodels/videos",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["dlModelVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodelvideo",
    label: "list dlmodel videos",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_DLMODEL_VIDEO = {
    action: "ADD_DLMODEL_VIDEO",
    resource: "DLMODELVIDEO",
    verb: "POST",
    endpoint: "/dlmodels/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel video",
    label: "add dlmodel video",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL_VIDEO = {
    action: "UPDATE_DLMODEL_VIDEO",
    resource: "DLMODELVIDEO",
    verb: "PUT",
    endpoint: "/dlmodels/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel video",
    label: "update dlmodel video",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_DLMODEL_VIDEO_STATUS = {
    action: "UPDATE_DLMODEL_VIDEO_STATUS",
    resource: "DLMODELVIDEO",
    verb: "PUT",
    endpoint: "/dlmodels/videos/status",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel video status",
    label: "update dlmodel video status",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_DLMODEL_VIDEO = {
    action: "DELETE_DLMODEL_VIDEO",
    resource: "DLMODELVIDEO",
    verb: "DELETE",
    endpoint: "/dlmodels/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["dlModelVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "dlmodel video",
    label: "delete dlmodel video",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /* ------------------- DLMODELVIDEO --------------------- */

  Resources.GET_USERS_TOKENS = {
    action: "GET_USERS_TOKENS",
    resource: "TOKENS",
    verb: "GET",
    endpoint: "/users/tokens",
    sign_with: "RSK",
    type: "READ",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user tokens",
    label: "list user tokens",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.CREATE_USERS_TOKEN = {
    action: "CREATE_USERS_TOKEN",
    resource: "TOKENS",
    verb: "POST",
    endpoint: "/users/tokens",
    sign_with: "RSK",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user tokens",
    label: "create user tokens",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_USERS_TOKEN = {
    action: "UPDATE_USERS_TOKEN",
    resource: "TOKENS",
    verb: "PUT",
    endpoint: "/users/tokens",
    sign_with: "RSK",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user tokens",
    label: "update user tokens",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_USERS_TOKEN = {
    action: "DELETE_USERS_TOKEN",
    resource: "TOKENS",
    verb: "DELETE",
    endpoint: "/users/tokens",
    sign_with: "RSK",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user tokens",
    label: "delete user tokens",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.VALIDATE_USERS_TOKEN = {
    action: "VALIDATE_USERS_TOKEN",
    resource: "TOKENS",
    verb: "POST",
    endpoint: "/users/tokens/validate",
    sign_with: "",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user tokens",
    label: "validate user tokens",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_TOKEN_PERMISSIONS = {
    action: "GET_TOKEN_PERMISSIONS",
    resource: "TOKENS",
    verb: "GET",
    endpoint: "/users/tokens/permissions",
    sign_with: "TOKEN",
    type: "READ",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user token permissions",
    label: "list user token permissions",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.VALIDATE_TOKEN_PERMISSIONS = {
    action: "VALIDATE_TOKEN_PERMISSIONS",
    resource: "TOKENS",
    verb: "POST",
    endpoint: "/users/tokens/permissions/validate",
    sign_with: "",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "validate user token permissions",
    label: "validate user token permissions",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_TOKEN_PERMISSIONS = {
    action: "ADD_TOKEN_PERMISSIONS",
    resource: "PERMISSIONS",
    verb: "POST",
    endpoint: "/users/tokens/permissions",
    sign_with: "TOKEN",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user token permissions",
    label: "add user token permissions",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_TOKEN_PERMISSIONS = {
    action: "DELETE_TOKEN_PERMISSIONS",
    resource: "PERMISSIONS",
    verb: "DELETE",
    endpoint: "/users/tokens/permissions",
    sign_with: "TOKEN",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user token permissions",
    label: "delete user token permissions",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_USERS_PERMISSIONS = {
    action: "GET_USERS_PERMISSIONS",
    resource: "PERMISSIONS",
    verb: "GET",
    endpoint: "/users/permissions",
    sign_with: "TOKEN",
    type: "READ",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user permissions",
    label: "list user permissions",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_USERS_PERMISSIONS = {
    action: "ADD_USERS_PERMISSIONS",
    resource: "PERMISSIONS",
    verb: "POST",
    endpoint: "/users/permissions",
    sign_with: "TOKEN",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user permissions",
    label: "add user permissions",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_USERS_PERMISSIONS = {
    action: "DELETE_USERS_PERMISSIONS",
    resource: "PERMISSIONS",
    verb: "DELETE",
    endpoint: "/users/permissions",
    sign_with: "TOKEN",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user permissions",
    label: "delete user permissions",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_ROLES = {
    action: "GET_ROLES",
    resource: "ROLES",
    verb: "GET",
    endpoint: "/roles",
    sign_with: "",
    type: "READ",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user roles",
    label: "list user roles",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_WORKER_TYPE = {
    action: "UPDATE_WORKER_TYPE",
    resource: "WORKERS",
    verb: "PUT",
    endpoint: "/users/worker-type",
    sign_with: "",
    type: "READ",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user worker type",
    label: "update user worker type",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.VALIDATE_RSK = {
    action: "VALIDATE_RSK",
    resource: "USERS",
    verb: "POST",
    endpoint: "/users/rsk/validate",
    sign_with: "",
    type: "WRITE",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "user validate rsk",
    label: "validate user rsk",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_GROUPS = {
    action: "GET_GROUPS",
    resource: "GROUPS",
    verb: "GET",
    endpoint: "/projects/videos/groups",
    sign_with: "TOKEN",
    type: "READ",
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video groups",
    label: "list video groups",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  /* ------------------- FOLDER --------------------- */
  Resources.GET_FOLDERS = {
    action: "GET_FOLDERS",
    resource: "FOLDER",
    verb: "GET",
    endpoint: "/folders",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["folderId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "folder",
    label: "list folder",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_FOLDER = {
    action: "ADD_FOLDER",
    resource: "FOLDER",
    verb: "POST",
    endpoint: "/folders",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["folderId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "add folder",
    label: "add folder",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_FOLDER = {
    action: "UPDATE_FOLDER",
    resource: "FOLDER",
    verb: "PUT",
    endpoint: "/folders",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["folderId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "folder",
    label: "update folder",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_FOLDER = {
    action: "DELETE_FOLDER",
    resource: "FOLDER",
    verb: "DELETE",
    endpoint: "/folders",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["foldeId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "video",
    label: "delete video",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_FOLDER_VIDEOS = {
    action: "GET_FOLDER_VIDEOS",
    resource: "FOLDER VIDEOS",
    verb: "GET",
    endpoint: "/folders/videos",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["folderVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "folder video",
    label: "list folder video",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_FOLDER_VIDEO = {
    action: "ADD_FOLDER_VIDEO",
    resource: "FOLDER VIDEOS",
    verb: "POST",
    endpoint: "/folders/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["folderVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "folder videos",
    label: "add folder videos",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_FOLDER_VIDEOS = {
    action: "DELETE_FOLDER_VIDEOS",
    resource: "FOLDER VIDEOS",
    verb: "DELETE",
    endpoint: "/folders/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["folderVideoId"],
    request_processing_type: "SERIAL",
    API: "Labelling_API",
    feature_name: "folder videos",
    label: "delete folder videos",
    role_acl: [
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  /*-------------------infer videos------------------------*/
  Resources.GET_INFER_VIDEOS = {
    action: "GET_INFER_VIDEOS",
    resource: "INFER_VIDEO",
    verb: "GET",
    endpoint: "/videos",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videos",
    label: "list videos",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_INFER_VIDEOS = {
    action: "ADD_INFER_VIDEOS",
    resource: "INFER_VIDEO",
    verb: "POST",
    endpoint: "/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videos",
    label: "list videos",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFER_VIDEOS = {
    action: "UPDATE_INFER_VIDEOS",
    resource: "INFER_VIDEO",
    verb: "PUT",
    endpoint: "/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videos",
    label: "list videos",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFER_VIDEOS = {
    action: "UPDATE_INFER_VIDEOS",
    resource: "INFER_VIDEO",
    verb: "PUT",
    endpoint: "/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videos",
    label: "list videos",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_INFER_VIDEOS = {
    action: "DELETE_INFER_VIDEOS",
    resource: "INFER_VIDEO",
    verb: "DELETE",
    endpoint: "/videos",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videos",
    label: "list videos",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFER_VIDEO_STATUS = {
    action: "UPDATE_INFER_VIDEO_STATUS",
    resource: "INFER_VIDEO",
    verb: "PUT",
    endpoint: "/videos/status",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "video status",
    label: "update video status",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFER_VIDEO_METADATA = {
    action: "UPDATE_INFER_VIDEO_METADATA",
    resource: "INFER_VIDEO",
    verb: "PUT",
    endpoint: "/videos/metadata",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "video meta data",
    label: "update video meta data",
    role_acl: [
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.GET_INFER_VIDEO_URL = {
    action: "GET_INFER_VIDEO_URL",
    resource: "INFER_VIDEO",
    verb: "GET",
    endpoint: "/videos/video-url",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["videoId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "video url",
    label: "list video url",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /*-------------------infer videos------------------------*/

  /*-------------------infer video tasks------------------------*/
  Resources.GET_INFER_VIDEO_TASKS = {
    action: "GET_INFER_VIDEO_TASKS",
    resource: "INFER_VIDEO_TASK",
    verb: "GET",
    endpoint: "/videos/tasks",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_INFER_VIDEO_TASKS = {
    action: "ADD_INFER_VIDEO_TASKS",
    resource: "INFER_VIDEO_TASK",
    verb: "POST",
    endpoint: "/videos/tasks",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFER_VIDEO_TASKS = {
    action: "UPDATE_INFER_VIDEO_TASKS",
    resource: "INFER_VIDEO_TASK",
    verb: "PUT",
    endpoint: "/videos/tasks",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_INFER_VIDEO_TASKS = {
    action: "DELETE_INFER_VIDEO_TASKS",
    resource: "INFER_VIDEO_TASK",
    verb: "DELETE",
    endpoint: "/videos/tasks",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["videoTaskId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "videoTasks",
    label: "list videoTasks",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /*-------------------infer video tasks------------------------*/

  /*-------------------infer video detections------------------------*/
  Resources.GET_INFER_DETECTIONS = {
    action: "GET_INFER_DETECTIONS",
    resource: "INFER_DETECTION",
    verb: "GET",
    endpoint: "/detections",
    sign_with: "TOKEN",
    type: "READ",
    resource_ids: ["detectionId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "detections",
    label: "list detections",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.ADD_INFER_DETECTIONS = {
    action: "ADD_INFER_DETECTIONS",
    resource: "INFER_DETECTION",
    verb: "POST",
    endpoint: "/detections",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["detectionId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "detections",
    label: "list detections",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.UPDATE_INFER_DETECTIONS = {
    action: "UPDATE_INFER_DETECTIONS",
    resource: "INFER_DETECTION",
    verb: "PUT",
    endpoint: "/detections",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["detectionId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "detections",
    label: "list detections",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };

  Resources.DELETE_INFER_DETECTIONS = {
    action: "DELETE_INFER_DETECTIONS",
    resource: "INFER_DETECTION",
    verb: "DELETE",
    endpoint: "/detections",
    sign_with: "TOKEN",
    type: "WRITE",
    resource_ids: ["detectionId"],
    request_processing_type: "SERIAL",
    API: "LABELLING_INFER_API",
    feature_name: "detections",
    label: "list detections",
    role_acl: [
      {
        role: Roles.WORKER.role,
        account_restriction: true
      },
      {
        role: Roles.PUBLISHER.role,
        account_restriction: true
      },
      {
        role: Roles.ADMIN.role,
        account_restriction: false
      },
      {
        role: Roles.ROOT.role,
        account_restriction: false
      }
    ]
  };
  /*-------------------infer video detections------------------------*/


    /* ------------------- NOTIFCATIONS --------------------- */
    Resources.GET_EMAILS = {
      action: "GET_EMAILS",
      resource: "NOTIFICATION_EMAIL",
      verb: "GET",
      endpoint: "/emails",
      sign_with: "TOKEN",
      type: "READ",
      resource_ids: [""],
      request_processing_type: "SERIAL",
      API: "Labelling_Notification_API",
      feature_name: "fetch list of all emails",
      label: "list of all emails",
      role_acl: [
        {
          role: Roles.WORKER.role,
          account_restriction: true
        },
        {
          role: Roles.PUBLISHER.role,
          account_restriction: true
        },
        {
          role: Roles.ADMIN.role,
          account_restriction: false
        },
        {
          role: Roles.ROOT.role,
          account_restriction: false
        }
      ]
    };

    Resources.SEND_EMAIL = {
      action: "SEND_EMAIL",
      resource: "NOTIFICATION_EMAIL",
      verb: "POST",
      endpoint: "/emails",
      sign_with: "TOKEN",
      type: "WRITE",
      resource_ids: [""],
      request_processing_type: "SERIAL",
      API: "Labelling_Notification_API",
      feature_name: "send email",
      label: "send email",
      role_acl: [
        {
          role: Roles.PUBLISHER.role,
          account_restriction: true
        },
        {
          role: Roles.ADMIN.role,
          account_restriction: false
        },
        {
          role: Roles.ROOT.role,
          account_restriction: false
        }
      ]
    };

    Resources.UPDATE_EMAIL = {
      action: "UPDATE_EMAIL",
      resource: "NOTIFICATION_EMAIL",
      verb: "PUT",
      endpoint: "/emails",
      sign_with: "TOKEN",
      type: "WRITE",
      resource_ids: [""],
      request_processing_type: "SERIAL",
      API: "Labelling_Notification_API",
      feature_name: "update email",
      label: "update email",
      role_acl: [
        {
          role: Roles.PUBLISHER.role,
          account_restriction: true
        },
        {
          role: Roles.ADMIN.role,
          account_restriction: false
        },
        {
          role: Roles.ROOT.role,
          account_restriction: false
        }
      ]
    };

  Resources = Object.freeze(Resources);

  /* lock the object to prevent modification and export it */
  module.exports = Resources;
})();
