(function () {
  "use strict";

  var organizationOperations = function () {},
    Requests = require("../requests"),
    ErrorConstants = require("/etc/label-config/constants/errors"),
    ResourceConstants = require("/etc/label-config/constants/resources");

  /**
   * Requests sales admin for approval of newly registered account
   * REQUIRES AUTHENTICATION: params should contain the token key
   */
  organizationOperations.getOrganizations = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.GET_ORGANIZATIONS, token, headers)
      .send(params, callback);
  };

  /**
   * registers a organization for labelling
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  organizationOperations.registerOrganization = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.ORGANIZATIONS_REGISTER, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  organizationOperations.updateOrganization = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.UPDATE_ORGANIZATION, token, headers)
      .send(params, callback);
  };

  /**
   * Delete organization request to the API
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  organizationOperations.deleteOrganization = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.DELETE_ORGANIZATION, token, headers)
      .send(params, callback);
  };

  module.exports = organizationOperations;
})();
