(function () {
  "use strict";
  var Requests,
    request = require("request"),
    appConfig = require("../config/app"),
    Helpers = require("./helpers"),
    ErrorConstants = require("/etc/label-config/constants/errors"),
    _ = require("lodash"),
    defaultHeaders;

  defaultHeaders = {
    "Content-Type": "application/json",
    "Accept": "application/json",
    "User-Agent": "lams-node-sdk"
  };

  Requests = function (resourceConstant, token, headers) {
    if (!resourceConstant || typeof resourceConstant !== "object" || Array.isArray(resourceConstant)) {
      throw new ReferenceError("invalid resourceConstant object");
    }

    if (!resourceConstant.endpoint) {
      throw new ReferenceError("invalid resourceConstant object: endpoint key not found");
    }

    if (!resourceConstant.verb) {
      throw new ReferenceError("invalid resourceConstant object: verb key not found");
    }

    this.url = appConfig.apiUrl.labelAuthMs + resourceConstant.endpoint;

    this.headers = defaultHeaders;

    this.method = resourceConstant.verb;

    // if (headers && typeof headers === "object" && !Array.isArray(headers)) {
    //   this.headers = _.merge(this.headers, headers);
    // }

    this.headers["X-Fizz-Used-By"] = headers["X-Fizz-Used-By"] || headers["x-fizz-used-by"] || undefined;
    this.headers["X-Fizz-Host"] = headers["X-Fizz-Host"] || headers["x-fizz-host"] || undefined;

    if (resourceConstant.sign_with && resourceConstant.sign_with.length) {
      this.headers["Authorization"] = "Bearer " + token;
    }
  };

  /**
   * makes an HTTP(S) request and returns a callback with err, data, body
   * @param body
   * @param callback
   */
  Requests.prototype.send = function (body, callback) {
    var options = {
      url: this.url,
      headers: this.headers,
      method: this.method
    };

    if (this.method === "GET") {
      options.url += "?" + Helpers.objectToQueryParams(body);
    } else {
      options.json = true;
      options.body = body;
    }

    request(options, function (err, res, body) {

      try {
        body = JSON.parse(body);
      } catch (e) {}

      if (err && err.code === "ECONNREFUSED") {
        return callback(ErrorConstants.SERVICE_DOWN, body ? body.data : body, body);
      }

      if (!body || body.status === "ERROR") {
        return callback(Helpers.getErrorConstant(body.appStatusCode), body ? body.data : body, body);
      }

      return callback(null, body ? body.data : body, body);
    });
  };

  module.exports = Requests;
})();
