(function () {
  "use strict";

  var tokenOperations = function () {},
    Requests = require("../requests"),
    ErrorConstants = require("/etc/label-config/constants/errors"),
    ResourceConstants = require("/etc/label-config/constants/resources");

  /**
   * Requests sales admin for approval of newly registered account
   * REQUIRES AUTHENTICATION: params should contain the token key
   */
  tokenOperations.getTokens = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.GET_USERS_TOKENS, token, headers)
      .send(params, callback);
  };

  /**
   * registers a token for labelling
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.createToken = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.CREATE_USERS_TOKEN, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.updateToken = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.UPDATE_USERS_TOKEN, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.disableToken = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.DISABLE_USERS_TOKEN, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.validateToken = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    // delete params.token;

    new Requests(ResourceConstants.VALIDATE_USERS_TOKEN, token, headers)
      .send(params, callback);
  };

  /**
   * Delete token request to the API
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.deleteToken = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.DELETE_USERS_TOKEN, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.getTokenPermissions = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.GET_TOKEN_PERMISSIONS, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.validateTokenPermissions = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    // if (!params || !params.token) {
    //   return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    // }

    // token = params.token;
    // delete params.token;

    new Requests(ResourceConstants.VALIDATE_TOKEN_PERMISSIONS, null, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.createTokenPermissions = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.ADD_TOKEN_PERMISSIONS, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  tokenOperations.deleteTokenPermissions = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.DELETE_TOKEN_PERMISSIONS, token, headers)
      .send(params, callback);
  };

  module.exports = tokenOperations;
})();
