(function () {
  "use strict";

  var userOperations = function () {},
    Requests = require("../requests"),
    ErrorConstants = require("/etc/label-config/constants/errors"),
    ResourceConstants = require("/etc/label-config/constants/resources");

  /**
   * Requests sales admin for approval of newly registered account
   * REQUIRES AUTHENTICATION: params should contain the token key
   */
  userOperations.getUsers = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.GET_USERS, token, headers)
      .send(params, callback);
  };

  /**
   * registers a user for labelling
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.registerUser = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.USERS_REGISTER, token, headers)
      .send(params, callback);
  };

  /**
   * logs in a user for labelling
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.loginUser = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    // if (!params || !params.token) {
    //   return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    // }

    token = params.token || "";
    delete params.token;

    new Requests(ResourceConstants.USERS_LOGIN, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.updateUser = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.UPDATE_USER, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.disableUser = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.DISABLE_USER, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.updateUserPassword = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.UPDATE_USER_PASSWORD, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to reset her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.resetUserPassword = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    new Requests(ResourceConstants.RESET_USER_PASSWORD, null, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.updateUserWorkerType = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.UPDATE_WORKER_TYPE, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.validateRSK = function (params, headers, callback) {
    var rsk;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || (!params.rsk && !params.RSK && !params.rootSecretKey)) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    rsk = params.rsk || params.RSK || params.rootSecretKey;

    new Requests(ResourceConstants.VALIDATE_RSK, rsk, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.getUserPermissions = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.GET_USERS_PERMISSIONS, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.createUserPermissions = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.ADD_USERS_PERMISSIONS, token, headers)
      .send(params, callback);
  };

  /**
   * Requests external client to verify her/his email
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.deleteUserPermissions = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.DELETE_USERS_PERMISSIONS, token, headers)
      .send(params, callback);
  };

  /**
   * Delete user request to the API
   * REQUIRES AUTHENTICATION: params should contain the token key
   * @returns {*}
   */
  userOperations.deleteUser = function (params, headers, callback) {
    var token;

    if (typeof headers === "function") {
      callback = headers;
      headers = {};
    }

    typeof callback === "function" || (callback = function () {});

    if (!params || !params.token) {
      return callback(ErrorConstants.MISSING_AUTH_TOKEN, null);
    }

    token = params.token;
    delete params.token;

    new Requests(ResourceConstants.DELETE_USER, token, headers)
      .send(params, callback);
  };

  module.exports = userOperations;
})();
